@@ -176,7 +176,9 @@ class SPApi():
                            "interests", "pcs_farmer", "pcs_worker", "pcs_retirees", "pcs_intermediate_professions", "pcs_employee",
                            "pcs_student", "pcs_unemployed", "pcs_craftsmen", "pcs_managment_nd_profession", "vistor_type_new",
                            "vistor_type_frequent", "vistor_type_occasional", "vistor_type_everybody", "specific_duration", "keep_audio",
-                           "url", "file", "post_accounts", "webview_details", "webviewtemplate"])
+                           "url", "file", "post_accounts", "webview_details", "webviewtemplate", "rss_post_accounts", "twitter_post_accounts", "instagram_post_accounts",
+                           "facebook_post_accounts", "instagram_post_accounts", "banner_texts_details", "font", "font_size", "color", "bg_color", "bg_opacity", "speed",
+                           "position", "position_unset", "margin"])
     def add_media(self, category, **kwargs):
         # If file is given -> Double request: 1st Media File Upload -> 2nd add media
         if "file" in kwargs:
@@ -195,6 +197,29 @@ class SPApi():
         if "post_accounts" in kwargs:
             kwargs["post_accounts_text"] = ",".join(kwargs["post_accounts"])
             del kwargs["post_accounts"]
+        # Field convertion "rss_post_accounts" -> "rss_post_accounts_text"
+        if "rss_post_accounts" in kwargs:
+            kwargs["rss_post_accounts_text"] = ",".join(kwargs["rss_post_accounts"])
+            del kwargs["rss_post_accounts"]
+        # Field convertion "twitter_post_accounts" -> "twitter_post_accounts_text"
+        if "twitter_post_accounts" in kwargs:
+            kwargs["twitter_post_accounts_text"] = ",".join(kwargs["twitter_post_accounts"])
+            del kwargs["twitter_post_accounts"]
+        # Field convertion "instagram_post_accounts" -> "instagram_post_accounts_text"
+        if "instagram_post_accounts" in kwargs:
+            kwargs["instagram_post_accounts_text"] = ",".join(kwargs["instagram_post_accounts"])
+            del kwargs["instagram_post_accounts"]
+        # Field convertion "facebook_post_accounts" -> "facebook_post_accounts_text"
+        if "facebook_post_accounts" in kwargs:
+            kwargs["facebook_post_accounts_text"] = ",".join(kwargs["facebook_post_accounts"])
+            del kwargs["facebook_post_accounts"]
+        # Field convertion "instagram_post_accounts" -> "instagram_post_accounts_text"
+        if "instagram_post_accounts" in kwargs:
+            kwargs["instagram_post_accounts_text"] = ",".join(kwargs["instagram_post_accounts"])
+            del kwargs["instagram_post_accounts"]
+        # Field convertion "banner_texts_details" -> "banner_texts_details"
+        if "banner_texts_details" in kwargs:
+            kwargs["banner_texts_details"] = ",".join(kwargs["banner_texts_details"])
         # Field convertion "tags" -> "tags_text"
         if "tags" in kwargs:
             kwargs["tags_text"] = ",".join(kwargs["tags"])
@@ -216,7 +241,9 @@ class SPApi():
                            "interests", "pcs_farmer", "pcs_worker", "pcs_retirees", "pcs_intermediate_professions", "pcs_employee",
                            "pcs_student", "pcs_unemployed", "pcs_craftsmen", "pcs_managment_nd_profession", "vistor_type_new",
                            "vistor_type_frequent", "vistor_type_occasional", "vistor_type_everybody", "specific_duration", "keep_audio",
-                           "url", "file", "post_accounts", "webview_details", "webviewtemplate"])
+                           "url", "file", "post_accounts", "webview_details", "webviewtemplate", "rss_post_accounts", "twitter_post_accounts", "instagram_post_accounts",
+                           "facebook_post_accounts", "instagram_post_accounts", "banner_texts_details", "font", "font_size", "color", "bg_color", "bg_opacity", "speed",
+                           "position", "position_unset", "margin"])
     def edit_media(self, code, **kwargs):
         # If file is given -> Double request: 1st Media File Upload -> 2nd add media
         if "file" in kwargs:
@@ -235,6 +262,29 @@ class SPApi():
         if "post_accounts" in kwargs:
             kwargs["post_accounts_text"] = ",".join(kwargs["post_accounts"])
             del kwargs["post_accounts"]
+        # Field convertion "rss_post_accounts" -> "rss_post_accounts_text"
+        if "rss_post_accounts" in kwargs:
+            kwargs["rss_post_accounts_text"] = ",".join(kwargs["rss_post_accounts"])
+            del kwargs["rss_post_accounts"]
+        # Field convertion "twitter_post_accounts" -> "twitter_post_accounts_text"
+        if "twitter_post_accounts" in kwargs:
+            kwargs["twitter_post_accounts_text"] = ",".join(kwargs["twitter_post_accounts"])
+            del kwargs["twitter_post_accounts"]
+        # Field convertion "instagram_post_accounts" -> "instagram_post_accounts_text"
+        if "instagram_post_accounts" in kwargs:
+            kwargs["instagram_post_accounts_text"] = ",".join(kwargs["instagram_post_accounts"])
+            del kwargs["instagram_post_accounts"]
+        # Field convertion "facebook_post_accounts" -> "facebook_post_accounts_text"
+        if "facebook_post_accounts" in kwargs:
+            kwargs["facebook_post_accounts_text"] = ",".join(kwargs["facebook_post_accounts"])
+            del kwargs["facebook_post_accounts"]
+        # Field convertion "instagram_post_accounts" -> "instagram_post_accounts_text"
+        if "instagram_post_accounts" in kwargs:
+            kwargs["instagram_post_accounts_text"] = ",".join(kwargs["instagram_post_accounts"])
+            del kwargs["instagram_post_accounts"]
+        # Field convertion "banner_texts_details" -> "banner_texts_details"
+        if "banner_texts_details" in kwargs:
+            kwargs["banner_texts_details"] = ",".join(kwargs["banner_texts_details"])
         # Field convertion "tags" -> "tags_text"
         if "tags" in kwargs:
             kwargs["tags_text"] = ",".join(kwargs["tags"])
